@@ -474,6 +474,11 @@ qreal ContentItem::childWidth(QQuickItem *child)
         return qRound(parentItem()->width());
 
     } else if (attached->fillWidth()) {
+        if (m_view->count() == 1) {
+            // single column
+            return qRound(parentItem()->width());
+        }
+
         return qRound(qBound(m_columnWidth, (parentItem()->width() - attached->reservedSpace()), std::max(m_columnWidth, parentItem()->width())));
 
     } else if (m_columnResizeMode == ColumnView::FixedColumns) {
@@ -1290,6 +1295,7 @@ void ColumnView::insertItem(int pos, QQuickItem *item)
     attached->setOriginalParent(item->parentItem());
     attached->setShouldDeleteOnRemove(item->parentItem() == nullptr && QQmlEngine::objectOwnership(item) == QQmlEngine::JavaScriptOwnership);
     item->setParentItem(m_contentItem);
+    connect(item, &QQuickItem::implicitWidthChanged, this, &ColumnView::polish);
 
     item->forceActiveFocus();
 
@@ -1359,6 +1365,7 @@ void ColumnView::replaceItem(int pos, QQuickItem *item)
         attached->setOriginalParent(item->parentItem());
         attached->setShouldDeleteOnRemove(item->parentItem() == nullptr && QQmlEngine::objectOwnership(item) == QQmlEngine::JavaScriptOwnership);
         item->setParentItem(m_contentItem);
+        connect(item, &QQuickItem::implicitWidthChanged, this, &ColumnView::polish);
 
         if (attached->globalHeader()) {
             m_contentItem->connectHeader(nullptr, attached->globalHeader());
@@ -1589,6 +1596,16 @@ bool ColumnView::childMouseEventFilter(QQuickItem *item, QEvent *event)
             return false;
         }
 
+        // It's possible the synthetyzed mouse press event was not passed
+        // but now we get the mouse move events, consider the first move
+        // as the press
+        if (!m_mouseDown) {
+            m_mouseDown = true;
+            m_oldMouseX = m_startMouseX = mapFromItem(item, me->position()).x();
+            m_oldMouseY = m_startMouseY = mapFromItem(item, me->position()).y();
+            return false;
+        }
+
         const QPointF pos = mapFromItem(item, me->position());
 
         bool verticalScrollIntercepted = false;
