@@ -169,6 +169,7 @@ class ColumnView : public QQuickItem
      * * FixedColumns: every column is fixed at the same width of the columnWidth property
      * * DynamicColumns: columns take their width from their implicitWidth
      * * SingleColumn: only one column at a time is shown, as wide as the viewport, eventual reservedSpace on the column's attached property is ignored
+     * The default is FixedColumns.
      */
     Q_PROPERTY(ColumnResizeMode columnResizeMode READ columnResizeMode WRITE setColumnResizeMode NOTIFY columnResizeModeChanged FINAL)
 
@@ -229,7 +230,7 @@ class ColumnView : public QQuickItem
     /**
      * The list of all visible column items that are at least partially in the viewport at any given moment
      */
-    Q_PROPERTY(QList<QObject *> visibleItems READ visibleItems NOTIFY visibleItemsChanged FINAL)
+    Q_PROPERTY(QList<QQuickItem *> visibleItems READ visibleItems NOTIFY visibleItemsChanged FINAL)
 
     /**
      * The first of visibleItems provided from convenience
@@ -310,8 +311,7 @@ public:
 
     QQuickItem *currentItem();
 
-    // NOTE: It's a QList<QObject *> as QML can't correctly build an Array out of QList<QQuickItem*>
-    QList<QObject *> visibleItems() const;
+    QList<QQuickItem *> visibleItems() const;
     QQuickItem *leadingVisibleItem() const;
     QQuickItem *trailingVisibleItem() const;
 
